Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1225)

Unified Diff: services/dart/content_handler_app.h

Issue 2010283006: Almost done: ApplicationDelegate -> ApplicationImplBase conversion. (Closed) Base URL: https://github.com/domokit/mojo.git@work798-x-work797-x-work796_no_run_main_app
Patch Set: rebased Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mojo/ui/associates/view_tree_hit_tester_client_apptest.cc ('k') | services/dart/content_handler_app.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: services/dart/content_handler_app.h
diff --git a/services/dart/content_handler_app.h b/services/dart/content_handler_app.h
index a3ae75600160a909abc7450d0e48fd3d056da2f1..30c5ed1cf6ad69cedb71f9b41a9562c7f0aa1f9c 100644
--- a/services/dart/content_handler_app.h
+++ b/services/dart/content_handler_app.h
@@ -8,7 +8,7 @@
#include "base/bind.h"
#include "mojo/application/content_handler_factory.h"
#include "mojo/common/tracing_impl.h"
-#include "mojo/public/cpp/application/application_delegate.h"
+#include "mojo/public/cpp/application/application_impl_base.h"
#include "mojo/services/url_response_disk_cache/interfaces/url_response_disk_cache.mojom.h"
#include "services/dart/content_handler_app_service_connector.h"
#include "services/dart/dart_tracing.h"
@@ -38,7 +38,7 @@ class DartContentHandler : public mojo::ContentHandlerFactory::ManagedDelegate {
DISALLOW_COPY_AND_ASSIGN(DartContentHandler);
};
-class DartContentHandlerApp : public mojo::ApplicationDelegate {
+class DartContentHandlerApp : public mojo::ApplicationImplBase {
public:
DartContentHandlerApp();
@@ -51,11 +51,9 @@ class DartContentHandlerApp : public mojo::ApplicationDelegate {
bool run_on_message_loop() const;
private:
- // Overridden from mojo::ApplicationDelegate:
- void Initialize(mojo::ApplicationImpl* app) override;
-
- // Overridden from ApplicationDelegate:
- bool ConfigureIncomingConnection(
+ // Overridden from mojo::ApplicationImplBase:
+ void OnInitialize() override;
+ bool OnAcceptConnection(
mojo::ServiceProviderImpl* service_provider_impl) override;
mojo::TracingImpl tracing_;
@@ -69,6 +67,7 @@ class DartContentHandlerApp : public mojo::ApplicationDelegate {
DISALLOW_COPY_AND_ASSIGN(DartContentHandlerApp);
};
-}
+
+} // namespace dart
#endif // SERVICES_DART_CONTENT_HANDLER_APP_H_
« no previous file with comments | « mojo/ui/associates/view_tree_hit_tester_client_apptest.cc ('k') | services/dart/content_handler_app.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698